==> pchar-1.1.1.tar.gz: pchar-1.1.1/PctestIpv4.h <==
// -*- c++ -*-
//
// $Id: PctestIpv4.h,v 1.12 2000/01/19 17:14:42 bmah Exp $
//
// PctestIpv4.h
// Bruce A. Mah <bmah@ca.sandia.gov>
//
// This work was first produced by an employee of Sandia National
// Laboratories under a contract with the U.S. Department of Energy.
// Sandia National Laboratories dedicates whatever right, title or
// interest it may have in this software to the public. Although no
// license from Sandia is needed to copy and use this software,
// copying and using the software might infringe the rights of
// others. This software is provided as-is. SANDIA DISCLAIMS ANY
// WARRANTY OF ANY KIND, EXPRESS OR IMPLIED.
//
// Header class for IPv4 tests
//
#ifndef PCTESTIPV4_H
#define PCTESTIPV4_H

#if HAVE_UNISTD_H
#include <unistd.h>
#endif /* HAVE_UNISTD_H */

#if STDC_HEADERS
#include <string.h>
#endif /* STDC_HEADERS */

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>

#if HAVE_STRINGS_H
#include <strings.h>
#endif /* HAVE_STRINGS_H */

#include "pc.h"
#include "Pctest.h"
#include "TestRecord.h"

class PctestIpv4 : public Pctest {

  public:

    PctestIpv4() { 
	socketOut = 0;
	socketIn = 0;
	destPort = 32768; 
    };
    PctestIpv4(int p) { 
	socketOut = 0;
	socketIn = 0;
	destPort = p; 
    };
    virtual ~PctestIpv4() { 
	if (socketOut > 0) {
	    close(socketOut);
	}
	if (socketIn > 0) {
	    close(socketIn);
	}
    };

    virtual int SetTargetName(char *target);
    virtual int GetSocketOut() = 0;
    virtual int GetSocketIn();
    virtual char *GetPrintableAddress();
    virtual char *GetPrintableAddress(void *a);
    virtual char *GetName(void *a);
    virtual char *GetAddressFamily() { return "AF_INET"; };
    virtual int GetMinSize();
    virtual PctestActionType GetAction(TestRecord &tr);
    
  protected:

    struct in_addr targetAddress;
    struct sockaddr_in targetSocketAddress;

    int socketOut;		// output socket (RAW)
    int socketIn;		// input socket (ICMP)
    int proto;			// (hopefully) ICMP protocol number
    int destPort;		// destination port number

};

#endif /* PCTESTIPV4_H */

==> pchar-1.3.1.tar.gz: pchar-1.3.1/PctestIpv4.h <==
// -*- c++ -*-
//
// $Id: PctestIpv4.h,v 1.18 2001/01/19 22:18:46 bmah Exp $
//
// PctestIpv4.h
// Bruce A. Mah <bmah@acm.org>
//
// This work was first produced by an employee of Sandia National
// Laboratories under a contract with the U.S. Department of Energy.
// Sandia National Laboratories dedicates whatever right, title or
// interest it may have in this software to the public. Although no
// license from Sandia is needed to copy and use this software,
// copying and using the software might infringe the rights of
// others. This software is provided as-is. SANDIA DISCLAIMS ANY
// WARRANTY OF ANY KIND, EXPRESS OR IMPLIED.
//
// Header class for IPv4 tests
//
#ifndef PCTESTIPV4_H
#define PCTESTIPV4_H

#if HAVE_UNISTD_H
#include <unistd.h>
#endif /* HAVE_UNISTD_H */

#if STDC_HEADERS
#include <string.h>
#endif /* STDC_HEADERS */

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>

#if HAVE_STRINGS_H
#include <strings.h>
#endif /* HAVE_STRINGS_H */

#include "pc.h"
#include "Pctest.h"
#include "TestRecord.h"

class PctestIpv4 : public Pctest {

  public:

    PctestIpv4() { 
	socketOut = 0;
	socketIn = 0;
	destPort = 32768; 
    };
    PctestIpv4(int p) { 
	socketOut = 0;
	socketIn = 0;
	destPort = p; 
    };
    virtual ~PctestIpv4() { 
	if (socketOut > 0) {
	    close(socketOut);
	}
	if (socketIn > 0) {
	    close(socketIn);
	}
    };

    virtual int SetOriginName(char *origin);
    virtual void *GetOriginAddress() {return &originAddress;};
    virtual int SetTargetName(char *target);
    virtual int GetSocketIn();
    virtual char *GetPrintableAddress();
    virtual char *GetPrintableAddress(void *a);
    virtual char *GetName(void *a);
    virtual char *GetAddressFamilyString() { return "AF_INET"; };
    virtual int GetAddressFamily() { return (AF_INET); };
    
  protected:


    struct in_addr originAddress;
    struct in_addr targetAddress;
    struct sockaddr_in targetSocketAddress;

    int socketOut;		// output socket (RAW)
    int socketIn;		// input socket (ICMP)
    int proto;			// (hopefully) ICMP protocol number
    int destPort;		// destination port number

};

#endif /* PCTESTIPV4_H */
